Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(20)

Unified Diff: third_party/WebKit/Source/platform/heap/BlinkGCMemoryDumpProvider.cpp

Issue 1477023003: Refactor the Heap into ThreadHeap to prepare for per thread heaps Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/platform/heap/BlinkGCMemoryDumpProvider.cpp
diff --git a/third_party/WebKit/Source/platform/heap/BlinkGCMemoryDumpProvider.cpp b/third_party/WebKit/Source/platform/heap/BlinkGCMemoryDumpProvider.cpp
index eff025713ac88b9ee70b1ab98e6185148c65f32c..9afbf031b449933257e3ccdf623f690790604a02 100644
--- a/third_party/WebKit/Source/platform/heap/BlinkGCMemoryDumpProvider.cpp
+++ b/third_party/WebKit/Source/platform/heap/BlinkGCMemoryDumpProvider.cpp
@@ -19,14 +19,14 @@ void dumpMemoryTotals(blink::WebProcessMemoryDump* memoryDump)
{
String dumpName = String::format("blink_gc");
WebMemoryAllocatorDump* allocatorDump = memoryDump->createMemoryAllocatorDump(dumpName);
- allocatorDump->addScalar("size", "bytes", Heap::allocatedSpace());
+ allocatorDump->addScalar("size", "bytes", ThreadState::current()->allocatedSpace());
dumpName.append("/allocated_objects");
WebMemoryAllocatorDump* objectsDump = memoryDump->createMemoryAllocatorDump(dumpName);
// Heap::markedObjectSize() can be underestimated if we're still in the
// process of lazy sweeping.
- objectsDump->addScalar("size", "bytes", Heap::allocatedObjectSize() + Heap::markedObjectSize());
+ objectsDump->addScalar("size", "bytes", ThreadState::current()->allocatedObjectSize() + ThreadState::current()->markedObjectSize());
}
} // namespace
@@ -19,14 +19,14 @@ void dumpMemoryTotals(blink::WebProcessMemoryDump* memoryDump)
dumpName.append("/allocated_objects");
WebMemoryAllocatorDump* objectsDump = memoryDump->createMemoryAllocatorDump(dumpName);
- // Heap::markedObjectSize() can be underestimated if we're still in the
+ // ThreadState::markedObjectSize() can be underestimated if we're still in the
// process of lazy sweeping.

Powered by Google App Engine
This is Rietveld 408576698